TextSource

Trait TextSource 

pub trait TextSource:
    Debug
    + Send
    + Sync {
    // Required methods
    fn len(&self) -> usize;
    fn bytes_at(&self, index: usize) -> Result<Option<&[u8]>>;
    fn footprint(&self) -> usize;

    // Provided methods
    fn is_empty(&self) -> bool { ... }
    fn bytes_len_at(&self, index: usize) -> Result<Option<usize>> { ... }
    fn equal(&self, other: &dyn TextSource) -> bool { ... }
}
Random access to immutable text kept by a storage reader.

Required Methods

fn len(&self) -> usize

Number of values available.

fn bytes_at(&self, index: usize) -> Result<Option<&[u8]>>

Bytes at one position, or no value when the position is outside the source.

fn footprint(&self) -> usize

Resident bytes retained by this source.

Provided Methods

fn is_empty(&self) -> bool

Whether this source has no values.

fn bytes_len_at(&self, index: usize) -> Result<Option<usize>>

Byte length at one position without requiring the payload when the source has an index.

fn equal(&self, other: &dyn TextSource) -> bool

Whether another source presents the same values.